#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_SELECT_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_BITWISE_SELECT_HPP_INCLUDED

#include <boost/simd/bitwise/include/functions/simd/bitwise_select.hpp>

#endif
